@@ -4,7 +4,6 @@ This can be used for creation of Python REPLs.
 """
 import __future__
 
-import threading
 from asyncio import get_event_loop
 from functools import partial
 from typing import TYPE_CHECKING, Any, Callable, Dict, Generic, List, Optional, TypeVar
@@ -914,23 +913,13 @@ class PythonInput:
         else:
             self.editing_mode = EditingMode.EMACS
 
-    def _on_input_timeout(self, buff: Buffer, loop=None) -> None:
+    def _on_input_timeout(self, buff: Buffer) -> None:
         """
         When there is no input activity,
         in another thread, get the signature of the current code.
         """
-        app = self.app
 
-        # Never run multiple get-signature threads.
-        if self._get_signatures_thread_running:
-            return
-        self._get_signatures_thread_running = True
-
-        document = buff.document
-
-        loop = loop or get_event_loop()
-
-        def run():
+        def get_signatures_in_executor(document: Document) -> List[Signature]:
             # First, get signatures from Jedi. If we didn't found any and if
             # "dictionary completion" (eval-based completion) is enabled, then
             # get signatures using eval.
@@ -942,26 +931,47 @@ class PythonInput:
                     document, self.get_locals(), self.get_globals()
                 )
 
-            self._get_signatures_thread_running = False
+            return signatures
 
-            # Set signatures and redraw if the text didn't change in the
-            # meantime. Otherwise request new signatures.
-            if buff.text == document.text:
-                self.signatures = signatures
+        app = self.app
 
-                # Set docstring in docstring buffer.
-                if signatures:
-                    self.docstring_buffer.reset(
-                        document=Document(signatures[0].docstring, cursor_position=0)
+        async def on_timeout_task() -> None:
+            loop = get_event_loop()
+
+            # Never run multiple get-signature threads.
+            if self._get_signatures_thread_running:
+                return
+            self._get_signatures_thread_running = True
+
+            try:
+                while True:
+                    document = buff.document
+                    signatures = await loop.run_in_executor(
+                        None, get_signatures_in_executor, document
                     )
-                else:
-                    self.docstring_buffer.reset()
 
-                app.invalidate()
+                    # If the text didn't change in the meantime, take these
+                    # signatures. Otherwise, try again.
+                    if buff.text == document.text:
+                        break
+            finally:
+                self._get_signatures_thread_running = False
+
+            # Set signatures and redraw.
+            self.signatures = signatures
+
+            # Set docstring in docstring buffer.
+            if signatures:
+                self.docstring_buffer.reset(
+                    document=Document(signatures[0].docstring, cursor_position=0)
+                )
             else:
-                self._on_input_timeout(buff, loop=loop)
+                self.docstring_buffer.reset()
 
-        loop.run_in_executor(None, run)
+            app.invalidate()
+
+        if app.is_running:
+            app.create_background_task(on_timeout_task())
 
     def on_reset(self) -> None:
         self.signatures = []
@@ -1012,43 +1022,25 @@ class PythonInput:
                 self.app.vi_state.input_mode = InputMode.NAVIGATION
 
         # Run the UI.
-        result: str = ""
-        exception: Optional[BaseException] = None
-
-        def in_thread() -> None:
-            nonlocal result, exception
+        while True:
             try:
-                while True:
-                    try:
-                        result = self.app.run(pre_run=pre_run)
+                result = self.app.run(pre_run=pre_run, in_thread=True)
 
-                        if result.lstrip().startswith("\x1a"):
-                            # When the input starts with Ctrl-Z, quit the REPL.
-                            # (Important for Windows users.)
-                            raise EOFError
+                if result.lstrip().startswith("\x1a"):
+                    # When the input starts with Ctrl-Z, quit the REPL.
+                    # (Important for Windows users.)
+                    raise EOFError
 
-                        # Remove leading whitespace.
-                        # (Users can add extra indentation, which happens for
-                        # instance because of copy/pasting code.)
-                        result = unindent_code(result)
+                # Remove leading whitespace.
+                # (Users can add extra indentation, which happens for
+                # instance because of copy/pasting code.)
+                result = unindent_code(result)
 
-                        if result and not result.isspace():
-                            return
-                    except KeyboardInterrupt:
-                        # Abort - try again.
-                        self.default_buffer.document = Document()
-                    except BaseException as e:
-                        exception = e
-                        return
+                if result and not result.isspace():
+                    if self.insert_blank_line_after_input:
+                        self.app.output.write("\n")
 
-            finally:
-                if self.insert_blank_line_after_input:
-                    self.app.output.write("\n")
-
-        thread = threading.Thread(target=in_thread)
-        thread.start()
-        thread.join()
-
-        if exception is not None:
-            raise exception
-        return result
+                    return result
+            except KeyboardInterrupt:
+                # Abort - try again.
+                self.default_buffer.document = Document()
